Distribution: 	CCux
Packager: 	Karsten Brockmann <arcam@ccux-linux.de>

Name:		boost
Summary:	The Boost C++ Libraries
Version:	1.35.0
Release:	1
License:	Boost Software License (GPL-Compatible, Free Software License)
URL:		http://www.boost.org/
Group:		System Environment/Libraries
Source:		ttp://downloads.sourceforge.net/boost/boost_1_35_0.tar.bz2
# Tools required to build boost documentation
Source10:	http://mirrors.ibiblio.org/pub/mirrors/apache/xmlgraphics/fop/binaries/fop-0.94-bin-jdk1.4.tar.gz
Source11:	http://switch.dl.sourceforge.net/sourceforge/docbook/docbook-xsl-1.73.2.tar.gz
Source12:	http://www.oasis-open.org/docbook/xml/4.2/docbook-xml-4.2.zip

Patch0:		boost-configure.patch
Patch1:		boost-gcc-soname.patch
Patch2:		boost-use-rpm-optflags.patch
Patch3:		boost-run-tests.patch
Patch4:		boost-1.35.0-approve-gcc-4.4.patch

BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}

BuildRequires:	libstdc++-devel
BuildRequires:	bzip2-devel
BuildRequires:	zlib-devel
BuildRequires:	python-devel
BuildRequires:	libicu-devel

# Require for rpm lzma compression transition
Requires:        rpm >= 4.4.2.3-1

%description
Boost provides free peer-reviewed portable C++ source libraries.  The
emphasis is on libraries which work well with the C++ Standard
Library, in the hopes of establishing "existing practice" for
extensions and providing reference implementations so that the Boost
libraries are suitable for eventual standardization. (Some of the
libraries have already been proposed for inclusion in the C++
Standards Committee's upcoming C++ Standard Library Technical Report.)

%package	devel
Summary: 	The Boost C++ headers and development libraries
Group: 		Development/Libraries
Requires: 	boost = %{version}-%{release}

%description	devel
Headers, static libraries, and shared object symlinks for the Boost
C++ libraries

%package	doc
Summary:	The Boost C++ html docs
Group:		Documents
Requires:	boost = %{version}-%{release}

%description	doc
HTML documentation files for Boost C++ libraries

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%prep
rm -rf %{buildroot}

%setup -q -n %{name}_1_35_0
%patch0 -p0
%patch1 -p1 -b .soname~
%patch2 -p1 -b .optflags~
%patch3 -p0
%patch4 -p1 -b .gcccheck~

%build
export RPM_OPT_FLAGS="-Os -march=i686 -pipe -fomit-frame-pointer"
BOOST_ROOT=`pwd`
staged_dir=stage
export BOOST_ROOT

# build make tools, ie bjam, necessary for building libs, docs, and testing
(cd tools/jam/src && ./build.sh)
BJAM=`find tools/jam/src/ -name bjam -a -type f`

#BUILD_FLAGS="--with-toolset=gcc --prefix=$RPM_BUILD_ROOT%{_prefix}"
BUILD_FLAGS="--with-toolset=gcc"
PYTHON_VERSION=$(python -c 'import sys; print sys.version[:3]')
PYTHON_FLAGS="--with-python-root=/usr --with-python-version=$PYTHON_VERSION"
REGEX_FLAGS="--with-icu"
./configure $BUILD_FLAGS $PYTHON_FLAGS $REGEX_FLAGS 
make all

# build docs
cd ./doc
ln %{SOURCE10} %{SOURCE11} %{SOURCE12} .
chmod +x ../tools/boostbook/setup_boostbook.sh
../tools/boostbook/setup_boostbook.sh
$BOOST_ROOT/$BJAM --v2 -sICU_PATH=/usr --user-config=../user-config.jam html
cd ..

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%_libdir
mkdir -p $RPM_BUILD_ROOT%_includedir
mkdir -p $RPM_BUILD_ROOT%_docdir/boost-%{version}

# install lib
mkdir -p $RPM_BUILD_ROOT%_libdir
install -p -m 0644 stage/lib/* $RPM_BUILD_ROOT%_libdir/
cd $RPM_BUILD_ROOT%_libdir
for i in *-mt.so; do
	ln -s $i $i.%version
	ln -s $i $i.3
done
# needed symlinks for build other packages against libboost
ln -s libboost_date_time-mt.so libboost_date_time.so
ln -s libboost_filesystem-mt.so libboost_filesystem.so
ln -s libboost_graph-mt.so libboost_graph.so
ln -s libboost_iostreams-mt.so libboost_iostreams.so 
ln -s libboost_prg_exec_monitor-mt.so libboost_prg_exec_monitor.so
ln -s libboost_program_options-mt.so libboost_program_options.so
ln -s libboost_python-mt.so libboost_python.so
ln -s libboost_regex-mt.so libboost_regex.so
ln -s libboost_serialization-mt.so libboost_serialization.so
ln -s libboost_signals-mt.so libboost_signals.so
ln -s libboost_system-mt.so libboost_system.so
ln -s libboost_thread-mt.so libboost_thread.so
ln -s libboost_unit_test_framework-mt.so libboost_unit_test_framework.so
ln -s libboost_wave-mt.so libboost_wave.so
ln -s libboost_wserialization-mt.so libboost_wserialization.so
cd -

# install include files
mkdir -p $RPM_BUILD_ROOT%_includedir
cp -a boost $RPM_BUILD_ROOT%_includedir

#install doc files
mkdir -p $RPM_BUILD_ROOT%_docdir
cp -a doc/html $RPM_BUILD_ROOT%_docdir/%name-%version

%files
%defattr(-,root,root,-)
%_libdir/libboost_date_time-mt.so
%_libdir/libboost_date_time-mt.so.1.35.0
%_libdir/libboost_date_time-mt.so.3
%_libdir/libboost_filesystem-mt.so
%_libdir/libboost_filesystem-mt.so.1.35.0
%_libdir/libboost_filesystem-mt.so.3
%_libdir/libboost_graph-mt.so
%_libdir/libboost_graph-mt.so.1.35.0
%_libdir/libboost_graph-mt.so.3
%_libdir/libboost_iostreams-mt.so
%_libdir/libboost_iostreams-mt.so.1.35.0
%_libdir/libboost_iostreams-mt.so.3
%_libdir/libboost_prg_exec_monitor-mt.so
%_libdir/libboost_prg_exec_monitor-mt.so.1.35.0
%_libdir/libboost_prg_exec_monitor-mt.so.3
%_libdir/libboost_program_options-mt.so
%_libdir/libboost_program_options-mt.so.1.35.0
%_libdir/libboost_program_options-mt.so.3
%_libdir/libboost_python-mt.so
%_libdir/libboost_python-mt.so.1.35.0
%_libdir/libboost_python-mt.so.3
%_libdir/libboost_regex-mt.so
%_libdir/libboost_regex-mt.so.1.35.0
%_libdir/libboost_regex-mt.so.3
%_libdir/libboost_serialization-mt.so
%_libdir/libboost_serialization-mt.so.1.35.0
%_libdir/libboost_serialization-mt.so.3
%_libdir/libboost_signals-mt.so
%_libdir/libboost_signals-mt.so.1.35.0
%_libdir/libboost_signals-mt.so.3
%_libdir/libboost_system-mt.so
%_libdir/libboost_system-mt.so.1.35.0
%_libdir/libboost_system-mt.so.3
%_libdir/libboost_thread-mt.so
%_libdir/libboost_thread-mt.so.1.35.0
%_libdir/libboost_thread-mt.so.3
%_libdir/libboost_unit_test_framework-mt.so
%_libdir/libboost_unit_test_framework-mt.so.1.35.0
%_libdir/libboost_unit_test_framework-mt.so.3
%_libdir/libboost_wave-mt.so
%_libdir/libboost_wave-mt.so.1.35.0
%_libdir/libboost_wave-mt.so.3
%_libdir/libboost_wserialization-mt.so
%_libdir/libboost_wserialization-mt.so.1.35.0
%_libdir/libboost_wserialization-mt.so.3

%files devel
%defattr(-,root,root,-)
%_libdir/*.a
%_libdir/libboost_date_time.so
%_libdir/libboost_filesystem.so
%_libdir/libboost_graph.so
%_libdir/libboost_iostreams.so
%_libdir/libboost_prg_exec_monitor.so
%_libdir/libboost_program_options.so
%_libdir/libboost_python.so
%_libdir/libboost_regex.so
%_libdir/libboost_serialization.so
%_libdir/libboost_signals.so
%_libdir/libboost_system.so
%_libdir/libboost_thread.so
%_libdir/libboost_unit_test_framework.so
%_libdir/libboost_wave.so
%_libdir/libboost_wserialization.so
%_includedir/boost

%files doc
%defattr(-,root,root,-)
%doc %{_docdir}/boost-%{version}

%clean
rm -rf $RPM_BUILD_ROOT

%changelog
* Mon Jun 23 2008 Christian Wasem <wasem@ccux-linux.de> 1.35.0-1
- Version update
* Sat Jan 26 2008 Karsten Brockmann <arcam@ccux-linux.de> 1.34.1-3
- rebuilt against icu 3.8.1
* Fri Jan 25 2008 Christian Metzen <metzench@ccux-linux.de> 1.34.1-2
- rebuild against gcc 4.1.2
* Sun Aug 12 2007 Karsten Brockmann <arcam@ccux-linux.de> 1.34.1-1
- Version update
* Wed Jan 10 2007 Christian Metzen <metzench@ccux-linux.de> 1.33.1-2
- rebuild against gcc4.1.1
* Sun Dec 11 2005 Christian Metzen <metzench@ccux-linux.de> 1.33.1-1
- Version update, modified build process
* Mon Dec 05 2005 Christian Wasem <wasem@ccux-linux.de> 1.33.0-3
- tweaked specfile, moved more files to devel package
* Sat Dec 03 2005 Karsten Brockmann <arcam@ccux-linux.de> 1.33.0-2
- added generic symlink
* Tue Jul 19 2005 Karsten Brockmann <arcam@ccux-linux.de> 1.33.0-1
- Initial release
